==> plotly-3.4.2-py2.py3-none-any.whl: plotly/validators/bar/__init__.py <==
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._yaxis import YAxisValidator
from ._y0 import Y0Validator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xaxis import XAxisValidator
from ._x0 import X0Validator
from ._x import XValidator
from ._widthsrc import WidthsrcValidator
from ._width import WidthValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uid import UidValidator
from ._tsrc import TsrcValidator
from ._textsrc import TextsrcValidator
from ._textpositionsrc import TextpositionsrcValidator
from ._textposition import TextpositionValidator
from ._textfont import TextfontValidator
from ._text import TextValidator
from ._t import TValidator
from ._stream import StreamValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._rsrc import RsrcValidator
from ._r import RValidator
from ._outsidetextfont import OutsidetextfontValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._offsetsrc import OffsetsrcValidator
from ._offset import OffsetValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._insidetextfont import InsidetextfontValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._error_y import ErrorYValidator
from ._error_x import ErrorXValidator
from ._dy import DyValidator
from ._dx import DxValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._constraintext import ConstraintextValidator
from ._cliponaxis import CliponaxisValidator
from ._basesrc import BasesrcValidator
from ._base import BaseValidator

==> plotly-3.7.0-py2.py3-none-any.whl: plotly/validators/bar/__init__.py <==
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._yaxis import YAxisValidator
from ._y0 import Y0Validator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xaxis import XAxisValidator
from ._x0 import X0Validator
from ._x import XValidator
from ._widthsrc import WidthsrcValidator
from ._width import WidthValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._tsrc import TsrcValidator
from ._textsrc import TextsrcValidator
from ._textpositionsrc import TextpositionsrcValidator
from ._textposition import TextpositionValidator
from ._textfont import TextfontValidator
from ._text import TextValidator
from ._t import TValidator
from ._stream import StreamValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._rsrc import RsrcValidator
from ._r import RValidator
from ._outsidetextfont import OutsidetextfontValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._offsetsrc import OffsetsrcValidator
from ._offsetgroup import OffsetgroupValidator
from ._offset import OffsetValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._legendgroup import LegendgroupValidator
from ._insidetextfont import InsidetextfontValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hovertemplatesrc import HovertemplatesrcValidator
from ._hovertemplate import HovertemplateValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._error_y import ErrorYValidator
from ._error_x import ErrorXValidator
from ._dy import DyValidator
from ._dx import DxValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._constraintext import ConstraintextValidator
from ._cliponaxis import CliponaxisValidator
from ._basesrc import BasesrcValidator
from ._base import BaseValidator
from ._alignmentgroup import AlignmentgroupValidator
